@@ -111,9 +111,13 @@ class FileReader(object):
     @staticmethod
     def _open_cdf(file):
         try:
-            return cdflib.CDF(file.name)
+            f = file.name
         except AttributeError:
-            return cdflib.CDF(file)
+            f = file
+        try:
+            return cdflib.cdfread.CDF(f, string_encoding="utf-8")
+        except TypeError:
+            return cdflib.cdfread.CDF(f)
 
     @staticmethod
     def _ensure_list(attribute):
@@ -160,9 +164,16 @@ class FileReader(object):
         columns = set(self.variables)
         columns.remove("Timestamp")
         # Split columns according to those to be expanded into multiple columns
-        columns_to_expand = set(c for c in columns
-                                if c in DATANAMES_TO_FRAME_NAMES.keys()
-                                or "B_NEC" in c) if expand else set()
+        if expand:
+            columns_to_expand = set(c for c in columns
+                                    if c in DATANAMES_TO_FRAME_NAMES.keys()
+                                    or "B_NEC" in c)
+            # Avoid conflict with 2D AOB_FAC Quality variable
+            # when accessing AUX_OBS Quality
+            if any(["AUX_OBS" in s for s in self.sources]):
+                columns_to_expand.discard("Quality")
+        else:
+            columns_to_expand = set()
         columns_standard = columns.difference(columns_to_expand)
         # Initialise dataframe with Timestamp as index
         df = pandas.DataFrame(index=self.get_variable("Timestamp"))
@@ -325,7 +336,7 @@ class ReturnedDataFile(object):
     def open_cdf(self):
         """Returns the opened file as cdflib.CDF
         """
-        return cdflib.CDF(self._file.name)
+        return FileReader.open_cdf(self._file.name)
 
     def _write_new_data(self, data):
         """Replace the tempfile contents with 'data' (bytes)
